@@ -4,6 +4,8 @@ require 'specinfra/backend/ssh'
 require 'specinfra/backend/powershell/script_helper'
 require 'specinfra/backend/powershell/command'
 require 'specinfra/backend/cmd'
+require 'specinfra/backend/docker'
+require 'specinfra/backend/lxc'
 require 'specinfra/backend/winrm'
 require 'specinfra/backend/shellscript'
 require 'specinfra/backend/dockerfile'
