@@ -1,4 +1,5 @@
 require 'singleton'
+require 'specinfra/command_result'
 
 module SpecInfra
   module Backend
@@ -16,15 +17,18 @@ module SpecInfra
       def commands
         @commands
       end
-      
+
       def check_zero(cmd, *args)
-        ret = run_command(commands.send(cmd, *args))
-        ret[:exit_status] == 0
+        run_command(commands.send(cmd, *args)).success?
       end
 
       # Default action is to call check_zero with args
       def method_missing(meth, *args, &block)
-        check_zero(meth, *args)
+        if meth.to_s =~ /^check/
+          check_zero(meth, *args)
+        else
+          run_command(commands.send(meth, *args))
+        end
       end
     end
   end
