@@ -2,11 +2,17 @@ require "specinfra/command/base"
 
 # Linux
 require "specinfra/command/linux"
+require "specinfra/command/arch"
 require "specinfra/command/debian"
 require "specinfra/command/ubuntu"
 require "specinfra/command/gentoo"
 require "specinfra/command/plamo"
 require "specinfra/command/redhat"
+require "specinfra/command/redhat7"
+require "specinfra/command/suse"
+require "specinfra/command/opensuse"
+require "specinfra/command/fedora"
+require "specinfra/command/nixos"
 
 # Solaris
 require "specinfra/command/solaris"
@@ -18,5 +24,6 @@ require "specinfra/command/smartos"
 require "specinfra/command/aix"
 require "specinfra/command/darwin"
 require "specinfra/command/freebsd"
+require "specinfra/command/freebsd10"
+require "specinfra/command/openbsd"
 require "specinfra/command/windows"
-
