@@ -4,6 +4,9 @@ require 'specinfra/helper/detect_os'
 require 'specinfra/helper/backend'
 include SpecInfra::Helper::Backend
 
+require 'specinfra/helper/docker'
+require 'specinfra/helper/lxc'
+
 require 'specinfra/helper/configuration'
 
 require 'specinfra/helper/properties'
